@@ -6,6 +6,7 @@ BEGIN
 	require 5.000;
 
 	use strict;
+	use warnings;
 	use vars qw(
 		$VERSION
 
@@ -17,7 +18,7 @@ BEGIN
 		$n
 	);
 
-	$VERSION = "0.13";
+	$VERSION = "0.05";  # based on Date::Ethiopic v0.13
 
 	($false,$true) = (0,1);
 
@@ -371,6 +372,13 @@ None presently known.
 
 Daniel Yacob,  L<dyacob@cpan.org|mailto:dyacob@cpan.org>
 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2003-2025, Daniel Yacob C<< <dyacob@cpan.org> >>. All rights reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
+
 =head1 SEE ALSO
 
 Ethiopica L<http://ethiopica.sourceforge.net>
